import React from "react";
import { StaticImage, IGatsbyImageData, GatsbyImage, getImage } from "gatsby-plugin-image";

interface Props {
  image?: string | IGatsbyImageData;
  layout?: 'top' | 'left';
}


const CardImage = (props: Props) => {
  const {
    image,
    layout
  } = props;
  
  const classNameImage = (layout == 'top') ? 'object-cover w-full h-52' : 'h-full w-full object-cover' ;
  const classNameDivContainer = (layout == 'top') ? '' : 'min-w-[320px] max-w-[320px]' ;

  const imageNoAvailable = (
    <StaticImage 
      src='../../../images/no-image-available.jpg'
      alt="no-image-available"
      className={classNameImage}
    />
  )

  if (! image || typeof image == 'undefined') {
    return (
      <div className={classNameDivContainer}>
        {imageNoAvailable}
      </div>
    );
  }

  if (typeof image == 'string') {
    return (
      <div className={classNameDivContainer}>
        <img 
          src={image} 
          alt={image} 
          className={classNameImage}
        />
      </div>
    )
  }

  const img = getImage(image) ;
  if (typeof img == 'undefined') {
    return (
      <div className={classNameDivContainer}>
        {imageNoAvailable}
      </div>
    )
  }

  return (
    <div className={classNameDivContainer}>
      <GatsbyImage image={img} alt="gatsby-image" className={classNameImage}/>
    </div>
    
  )
};


export default CardImage;