import React from "react";
import { useStaticQuery, graphql, Link } from "gatsby";

import { Disclosure } from "@headlessui/react";
import { MenuIcon, XIcon } from "@heroicons/react/outline";

import { Search } from "@onegeo/gatsby-theme-onegeo";

import logoSig from "../images/logo-egeo.png";

interface Props {
  template?: String;
  UserMenu?: React.ReactNode;
}

const Header = (props: Props) => {
  const data = useStaticQuery(
    graphql`
      query {
        api {
          site {
            name
            title
            logo
          }
          pages(
            where: {
              page_categories: { category: { name: { _eq: "header" } } }
            }
            order_by: { position: asc }
          ) {
            id
            author
            image_url
            created_at
            updated_at
            title
            published
            position
            toc
          }
        }
      }
    `
  );
  // const data = {
  //   api: {
  //     site: [{}],
  //     pages: [
  //       {
  //         title: "titre",
  //       },
  //     ],
  //   },
  // };
  const site = { ...data.api.site[0] };
  const pages = { ...data.api.pages };

  const pageItems = Object.keys(pages).map(function (index) {
    let page =
      pages[index].title
        .toLowerCase()
        .normalize("NFD")
        .replace(/[\u0300-\u036f]/g, "") == "actualites"
        ? "news"
        : pages[index].title
            .toLowerCase()
            .normalize("NFD")
            .replace(/[\u0300-\u036f]/g, "");

    return (
      <Link
        key={"navabar_item_" + pages[index].id}
        to={"/" + page}
        className="border-transparent hover:border-project-primary text-gray-900 inline-flex items-center px-4 pt-1 border-b-2 text-sm font-medium"
      >
        {pages[index].title}
      </Link>
    );
  });

  const pageMobileItems = Object.keys(pages).map(function (index) {
    return (
      <Disclosure.Button
        key={"navabar_mobile_item_" + pages[index].id}
        // @ts-ignore
        href={
          "/" +
          pages[index].title
            .toLowerCase()
            .normalize("NFD")
            .replace(/[\u0300-\u036f]/g, "")
        }
        className="border-transparent text-gray-600 hover:bg-gray-50 hover:border-gray-300 hover:text-gray-800 block pl-3 pr-4 py-2 border-l-4 text-base font-medium"
      >
        {pages[index].title}
      </Disclosure.Button>
    );
  });

  return (
    <Disclosure
      as="nav"
      key="navbar"
      className="bg-white shadow-sm fixed w-full z-50"
    >
      {({ open }) => (
        <>
          <div className="max-w-7xl mx-auto px-2 sm:px-4 lg:px-8">
            <div className="flex justify-between h-16">
              <div className="flex px-2 lg:px-0">
                <div className="flex-shrink-0 flex items-center">
                  <Link to="/" aria-label="Back to homepage" className="">
                    <img src={logoSig} alt="logo" className="h-8 " />
                  </Link>
                </div>
                <div className="hidden lg:ml-6 lg:flex lg:space-x-8 pl-4">
                  {pageItems}
                </div>
              </div>

              <div className="flex items-center lg:hidden">
                {/* Mobile menu button */}
                <Disclosure.Button className="inline-flex items-center justify-center p-2 rounded-md text-gray-400 hover:text-gray-500 hover:bg-gray-100 focus:outline-none focus:ring-2 focus:ring-inset focus:ring-project-primary">
                  <span className="sr-only">Open main menu</span>
                  {open ? (
                    <XIcon className="block h-6 w-6" aria-hidden="true" />
                  ) : (
                    <MenuIcon className="block h-6 w-6" aria-hidden="true" />
                  )}
                </Disclosure.Button>
              </div>
              <div className="hidden lg:ml-4 lg:flex lg:items-center">
                <Search />

                {props.UserMenu}
              </div>
            </div>
          </div>
          <Disclosure.Panel className="block lg:hidden bg-white shadow">
            <div className="pt-2 pb-3 space-y-1">{pageMobileItems}</div>

            {props.UserMenu}
          </Disclosure.Panel>
        </>
      )}
    </Disclosure>
  );
};

export default Header;
